pub enum ReadError {
Shapeless(String),
Missing(String),
Stranger(String),
NotIn(String, Dimension, String),
}Expand description
Why that text is not a point of this space.
Variants
Shapeless(String)
A piece with no = in it.
Missing(String)
A knob of this space the text says nothing about.
Stranger(String)
A name that is not a knob of this space.
NotIn(String, Dimension, String)
A value that is not one this knob could take.